==> cayenne-3.1.3-src.tar.gz: cayenne-3.1.3-src/modeler/cayenne-modeler/src/test/java/org/apache/cayenne/configuration/event/DataNodeEventTest.java <==
/*****************************************************************
 *   Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 ****************************************************************/

package org.apache.cayenne.configuration.event;

import junit.framework.TestCase;

import org.apache.cayenne.configuration.DataNodeDescriptor;
import org.apache.cayenne.map.event.MapEvent;

/**
 */
public class DataNodeEventTest extends TestCase {

    public void testNewName() throws Exception {
        MapEvent event = new DataNodeEvent(new Object(), new DataNodeDescriptor("someName"));
        assertEquals("someName", event.getNewName());
    }

    public void testNoNameChange() throws Exception {
        MapEvent event = new DataNodeEvent(new Object(), new DataNodeDescriptor("someName"));
        assertFalse(event.isNameChange());
        
        event.setOldName("someOldName");
        assertTrue(event.isNameChange());
    }

    public void testNameChange() throws Exception {
        MapEvent event = new DataNodeEvent(
                new Object(),
                new DataNodeDescriptor("someName"),
                "someOldName");
        assertEquals("someName", event.getNewName());
        assertTrue(event.isNameChange());
    }

}

==> cayenne-4.0.3-src.tar.gz: cayenne-4.0.3-src/modeler/cayenne-modeler/src/test/java/org/apache/cayenne/configuration/event/DataNodeEventTest.java <==
/*****************************************************************
 *   Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 ****************************************************************/

package org.apache.cayenne.configuration.event;

import org.apache.cayenne.configuration.DataNodeDescriptor;
import org.apache.cayenne.map.event.MapEvent;
import org.junit.Test;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

/**
 */
public class DataNodeEventTest {

    @Test
    public void testNewName() throws Exception {
        MapEvent event = new DataNodeEvent(new Object(), new DataNodeDescriptor("someName"));
        assertEquals("someName", event.getNewName());
    }

    @Test
    public void testNoNameChange() throws Exception {
        MapEvent event = new DataNodeEvent(new Object(), new DataNodeDescriptor("someName"));
        assertFalse(event.isNameChange());
        
        event.setOldName("someOldName");
        assertTrue(event.isNameChange());
    }

    @Test
    public void testNameChange() throws Exception {
        MapEvent event = new DataNodeEvent(
                new Object(),
                new DataNodeDescriptor("someName"),
                "someOldName");
        assertEquals("someName", event.getNewName());
        assertTrue(event.isNameChange());
    }

}
